==> infima_client-0.186.0-py3-none-any.whl: infima_client/api/cohort_service/cohort_service_get_historical_prepayments.py <==
from typing import Any, Dict, Optional, Union

import httpx

from ...client import Client
from ...models.cohort_historical_prepayments import CohortHistoricalPrepayments
from ...models.cohort_historical_prepayments_error import (
    CohortHistoricalPrepaymentsError,
)
from ...models.cohort_historical_prepayments_not_found import (
    CohortHistoricalPrepaymentsNotFound,
)
from ...models.cohort_historical_prepayments_unauthorized import (
    CohortHistoricalPrepaymentsUnauthorized,
)
from ...models.cohort_service_get_historical_prepayments_convention import (
    CohortService_GetHistoricalPrepaymentsConvention,
)
from ...types import UNSET, Response, Unset


def _get_kwargs(
    *,
    client: Client,
    cohort: str,
    periodyear: Union[Unset, int] = UNSET,
    periodmonth: Union[Unset, int] = UNSET,
    convention: Union[
        Unset, CohortService_GetHistoricalPrepaymentsConvention
    ] = CohortService_GetHistoricalPrepaymentsConvention.PERIOD,
    num_months: Union[Unset, int] = UNSET,
) -> Dict[str, Any]:
    url = "{}/api/v1/cohorts/prepayment_history".format(client.base_url)

    headers: Dict[str, Any] = client.get_headers()

    json_convention: Union[
        Unset, CohortService_GetHistoricalPrepaymentsConvention
    ] = UNSET
    if not isinstance(convention, Unset):
        json_convention = convention

    params: Dict[str, Any] = {
        "cohort": cohort,
        "period.year": periodyear,
        "period.month": periodmonth,
        "convention": json_convention,
        "numMonths": num_months,
    }
    params = {k: v for k, v in params.items() if v is not UNSET and v is not None}

    return {
        "url": url,
        "headers": headers,
        "cookies": client.get_cookies(),
        "timeout": client.get_timeout(),
        "params": params,
    }


def _parse_response(
    *, response: httpx.Response
) -> Optional[
    Union[
        CohortHistoricalPrepayments,
        CohortHistoricalPrepaymentsUnauthorized,
        CohortHistoricalPrepaymentsNotFound,
        CohortHistoricalPrepaymentsError,
    ]
]:
    if response.status_code == 200:
        response_200 = CohortHistoricalPrepayments.from_dict(response.json())

        return response_200
    if response.status_code == 401:
        response_401 = CohortHistoricalPrepaymentsUnauthorized.from_dict(
            response.json()
        )

        return response_401
    if response.status_code == 404:
        response_404 = CohortHistoricalPrepaymentsNotFound.from_dict(response.json())

        return response_404
    if response.status_code == 500:
        response_500 = CohortHistoricalPrepaymentsError.from_dict(response.json())

        return response_500
    return None


def _build_response(
    *, response: httpx.Response
) -> Response[
    Union[
        CohortHistoricalPrepayments,
        CohortHistoricalPrepaymentsUnauthorized,
        CohortHistoricalPrepaymentsNotFound,
        CohortHistoricalPrepaymentsError,
    ]
]:
    return Response(
        status_code=response.status_code,
        content=response.content,
        headers=response.headers,
        parsed=_parse_response(response=response),
    )


def sync_detailed(
    *,
    client: Client,
    cohort: str,
    periodyear: Union[Unset, int] = UNSET,
    periodmonth: Union[Unset, int] = UNSET,
    convention: Union[
        Unset, CohortService_GetHistoricalPrepaymentsConvention
    ] = CohortService_GetHistoricalPrepaymentsConvention.PERIOD,
    num_months: Union[Unset, int] = UNSET,
) -> Response[
    Union[
        CohortHistoricalPrepayments,
        CohortHistoricalPrepaymentsUnauthorized,
        CohortHistoricalPrepaymentsNotFound,
        CohortHistoricalPrepaymentsError,
    ]
]:
    kwargs = _get_kwargs(
        client=client,
        cohort=cohort,
        periodyear=periodyear,
        periodmonth=periodmonth,
        convention=convention,
        num_months=num_months,
    )

    response = httpx.get(
        **kwargs,
    )

    return _build_response(response=response)


def sync(
    *,
    client: Client,
    cohort: str,
    periodyear: Union[Unset, int] = UNSET,
    periodmonth: Union[Unset, int] = UNSET,
    convention: Union[
        Unset, CohortService_GetHistoricalPrepaymentsConvention
    ] = CohortService_GetHistoricalPrepaymentsConvention.PERIOD,
    num_months: Union[Unset, int] = UNSET,
) -> Optional[
    Union[
        CohortHistoricalPrepayments,
        CohortHistoricalPrepaymentsUnauthorized,
        CohortHistoricalPrepaymentsNotFound,
        CohortHistoricalPrepaymentsError,
    ]
]:
    """


    Args:
        cohort: Cohort to fetch.
        periodyear: Year of the period. Must be from 1 to 9999, or 0 to specify a date without a year
        periodmonth: Month of a year. Must be from 1 to 12, or 0 to specify a year without a month and day.
        convention: Convention to use for the date, can be PERIOD or FACTOR_DATE.
        num_months: None

    Returns:
        Either a valid response or an unauthorized, not found or other error.
    """

    return sync_detailed(
        client=client,
        cohort=cohort,
        periodyear=periodyear,
        periodmonth=periodmonth,
        convention=convention,
        num_months=num_months,
    ).parsed


async def asyncio_detailed(
    *,
    client: Client,
    cohort: str,
    periodyear: Union[Unset, int] = UNSET,
    periodmonth: Union[Unset, int] = UNSET,
    convention: Union[
        Unset, CohortService_GetHistoricalPrepaymentsConvention
    ] = CohortService_GetHistoricalPrepaymentsConvention.PERIOD,
    num_months: Union[Unset, int] = UNSET,
) -> Response[
    Union[
        CohortHistoricalPrepayments,
        CohortHistoricalPrepaymentsUnauthorized,
        CohortHistoricalPrepaymentsNotFound,
        CohortHistoricalPrepaymentsError,
    ]
]:
    kwargs = _get_kwargs(
        client=client,
        cohort=cohort,
        periodyear=periodyear,
        periodmonth=periodmonth,
        convention=convention,
        num_months=num_months,
    )

    async with httpx.AsyncClient() as _client:
        response = await _client.get(**kwargs)

    return _build_response(response=response)


async def asyncio(
    *,
    client: Client,
    cohort: str,
    periodyear: Union[Unset, int] = UNSET,
    periodmonth: Union[Unset, int] = UNSET,
    convention: Union[
        Unset, CohortService_GetHistoricalPrepaymentsConvention
    ] = CohortService_GetHistoricalPrepaymentsConvention.PERIOD,
    num_months: Union[Unset, int] = UNSET,
) -> Optional[
    Union[
        CohortHistoricalPrepayments,
        CohortHistoricalPrepaymentsUnauthorized,
        CohortHistoricalPrepaymentsNotFound,
        CohortHistoricalPrepaymentsError,
    ]
]:
    """  """

    return (
        await asyncio_detailed(
            client=client,
            cohort=cohort,
            periodyear=periodyear,
            periodmonth=periodmonth,
            convention=convention,
            num_months=num_months,
        )
    ).parsed

==> infima_client-0.259.0-py3-none-any.whl: infima_client/api/cohort_service/cohort_service_get_historical_prepayments.py <==
from typing import Any, Dict, Optional, Union

import httpx

from ...client import Client
from ...models.cohort_historical_prepayments import CohortHistoricalPrepayments
from ...models.cohort_historical_prepayments_error import (
    CohortHistoricalPrepaymentsError,
)
from ...models.cohort_historical_prepayments_not_found import (
    CohortHistoricalPrepaymentsNotFound,
)
from ...models.cohort_historical_prepayments_unauthorized import (
    CohortHistoricalPrepaymentsUnauthorized,
)
from ...models.cohort_service_get_historical_prepayments_json_body import (
    CohortService_GetHistoricalPrepaymentsJsonBody,
)
from ...types import Response


def _get_kwargs(
    *,
    client: Client,
    json_body: CohortService_GetHistoricalPrepaymentsJsonBody,
) -> Dict[str, Any]:
    url = "{}/api/v1/cohorts/prepayment_histories".format(client.base_url)

    headers: Dict[str, Any] = client.get_headers()

    json_json_body = json_body.to_dict()

    return {
        "url": url,
        "headers": headers,
        "cookies": client.get_cookies(),
        "timeout": client.get_timeout(),
        "json": json_json_body,
    }


def _parse_response(
    *, response: httpx.Response
) -> Optional[
    Union[
        CohortHistoricalPrepayments,
        CohortHistoricalPrepaymentsUnauthorized,
        CohortHistoricalPrepaymentsNotFound,
        CohortHistoricalPrepaymentsError,
    ]
]:
    if response.status_code == 200:
        response_200 = CohortHistoricalPrepayments.from_dict(response.json())

        return response_200
    if response.status_code == 401:
        response_401 = CohortHistoricalPrepaymentsUnauthorized.from_dict(
            response.json()
        )

        return response_401
    if response.status_code == 404:
        response_404 = CohortHistoricalPrepaymentsNotFound.from_dict(response.json())

        return response_404
    if response.status_code == 500:
        response_500 = CohortHistoricalPrepaymentsError.from_dict(response.json())

        return response_500
    return None


def _build_response(
    *, response: httpx.Response
) -> Response[
    Union[
        CohortHistoricalPrepayments,
        CohortHistoricalPrepaymentsUnauthorized,
        CohortHistoricalPrepaymentsNotFound,
        CohortHistoricalPrepaymentsError,
    ]
]:
    return Response(
        status_code=response.status_code,
        content=response.content,
        headers=response.headers,
        parsed=_parse_response(response=response),
    )


def sync_detailed(
    *,
    client: Client,
    json_body: CohortService_GetHistoricalPrepaymentsJsonBody,
) -> Response[
    Union[
        CohortHistoricalPrepayments,
        CohortHistoricalPrepaymentsUnauthorized,
        CohortHistoricalPrepaymentsNotFound,
        CohortHistoricalPrepaymentsError,
    ]
]:
    kwargs = _get_kwargs(
        client=client,
        json_body=json_body,
    )

    response = httpx.post(
        **kwargs,
    )

    return _build_response(response=response)


def sync(
    *,
    client: Client,
    json_body: CohortService_GetHistoricalPrepaymentsJsonBody,
) -> Optional[
    Union[
        CohortHistoricalPrepayments,
        CohortHistoricalPrepaymentsUnauthorized,
        CohortHistoricalPrepaymentsNotFound,
        CohortHistoricalPrepaymentsError,
    ]
]:
    """


    Args:

    Returns:
        Either a valid response or an unauthorized, not found or other error.
    """

    return sync_detailed(
        client=client,
        json_body=json_body,
    ).parsed


async def asyncio_detailed(
    *,
    client: Client,
    json_body: CohortService_GetHistoricalPrepaymentsJsonBody,
) -> Response[
    Union[
        CohortHistoricalPrepayments,
        CohortHistoricalPrepaymentsUnauthorized,
        CohortHistoricalPrepaymentsNotFound,
        CohortHistoricalPrepaymentsError,
    ]
]:
    kwargs = _get_kwargs(
        client=client,
        json_body=json_body,
    )

    async with httpx.AsyncClient() as _client:
        response = await _client.post(**kwargs)

    return _build_response(response=response)


async def asyncio(
    *,
    client: Client,
    json_body: CohortService_GetHistoricalPrepaymentsJsonBody,
) -> Optional[
    Union[
        CohortHistoricalPrepayments,
        CohortHistoricalPrepaymentsUnauthorized,
        CohortHistoricalPrepaymentsNotFound,
        CohortHistoricalPrepaymentsError,
    ]
]:
    """  """

    return (
        await asyncio_detailed(
            client=client,
            json_body=json_body,
        )
    ).parsed
